@@ -27,11 +27,11 @@ TAP::Parser - Parse L<TAP|Test::Harness::TAP> output
 
 =head1 VERSION
 
-Version 3.31
+Version 3.41
 
 =cut
 
-our $VERSION = '3.31';
+our $VERSION = '3.41';
 
 my $DEFAULT_TAP_VERSION = 12;
 my $MAX_TAP_VERSION     = 13;
@@ -60,6 +60,8 @@ BEGIN {    # making accessors
           in_todo
           start_time
           end_time
+          start_times
+          end_times
           skip_all
           grammar_class
           result_factory_class
@@ -95,7 +97,7 @@ L<http://testanything.org>
 
 It includes the TAP::Parser Cookbook:
 
-L<http://testanything.org/wiki/index.php/TAP::Parser_Cookbook>
+L<http://testanything.org/testing-with-tap/perl/tap::parser-cookbook.html>
 
 =head1 METHODS
 
@@ -1007,11 +1009,20 @@ were skipped.
 
 =head3 C<start_time>
 
-Returns the time when the Parser was created.
+Returns the wall-clock time when the Parser was created.
 
 =head3 C<end_time>
 
-Returns the time when the end of TAP input was seen.
+Returns the wall-clock time when the end of TAP input was seen.
+
+=head3 C<start_times>
+
+Returns the CPU times (like L<perlfunc/times> when the Parser was created.
+
+=head3 C<end_times>
+
+Returns the CPU times (like L<perlfunc/times> when the end of TAP
+input was seen.
 
 =head3 C<has_problems>
 
@@ -1374,6 +1385,7 @@ sub _iter {
     my $state_table = $self->_make_state_table;
 
     $self->start_time( $self->get_time );
+    $self->start_times( $self->get_times );
 
     # Make next_state closure
     my $next_state = sub {
@@ -1466,6 +1478,7 @@ sub _finish {
     my $self = shift;
 
     $self->end_time( $self->get_time );
+    $self->end_times( $self->get_times );
 
     # Avoid leaks
     $self->_iterator(undef);
